==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridMasterDetailContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridMasterDetailContextDescription } from "./WebGridMasterDetailContextDescription";
/**
 * @hidden
 */
export let WebGridMasterDetailContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridMasterDetailContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridMasterDetailContextDescriptionMetadata.a == null) {
                WebGridMasterDetailContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridMasterDetailContextDescriptionMetadata.c(WebGridMasterDetailContextDescriptionMetadata.a);
            }
            if (a.j(WebGridMasterDetailContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridMasterDetailContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridMasterDetailContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "Unknown");
            a.item("Index", "Number:double");
        }
        static d(a) {
            WebGridMasterDetailContextDescriptionMetadata.b(a);
            a.aa("WebGridMasterDetailContext", () => new WebGridMasterDetailContextDescription());
            a.z("WebGridMasterDetailContext", WebGridMasterDetailContextDescriptionMetadata.a);
        }
    }
    WebGridMasterDetailContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridMasterDetailContextDescriptionMetadata, 'WebGridMasterDetailContextDescriptionMetadata');
    WebGridMasterDetailContextDescriptionMetadata.a = null;
    return WebGridMasterDetailContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridMasterDetailContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridMasterDetailContextDescription } from "./WebGridMasterDetailContextDescription";
/**
 * @hidden
 */
export let WebGridMasterDetailContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridMasterDetailContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridMasterDetailContextDescriptionMetadata.a == null) {
                WebGridMasterDetailContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridMasterDetailContextDescriptionMetadata.c(WebGridMasterDetailContextDescriptionMetadata.a);
            }
            if (a.k(WebGridMasterDetailContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridMasterDetailContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridMasterDetailContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "Unknown");
            a.item("Index", "Number:double");
        }
        static d(a) {
            WebGridMasterDetailContextDescriptionMetadata.b(a);
            a.ac("WebGridMasterDetailContext", () => new WebGridMasterDetailContextDescription());
            a.ab("WebGridMasterDetailContext", WebGridMasterDetailContextDescriptionMetadata.a);
        }
    }
    WebGridMasterDetailContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridMasterDetailContextDescriptionMetadata, 'WebGridMasterDetailContextDescriptionMetadata');
    WebGridMasterDetailContextDescriptionMetadata.a = null;
    return WebGridMasterDetailContextDescriptionMetadata;
})();
